Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Connector ¶
type Connector interface {
Connect(ctx context.Context, hostAddr, hostName, user string) (*executor.Remote, error)
}
Connector is an interface for connecting to a host, and returning remote executer.
type Playbook ¶ added in v1.6.0
type Playbook interface {
AllTasks() []config.Task
Task(name string) (*config.Task, error)
TasksByTag(tag string) []string
TargetHosts(name string) ([]config.Destination, error)
AllSecretValues() []string
UpdateTasksTargets(vars map[string]string)
UpdateRegisteredVars(vars map[string]string)
}
Playbook is an interface for getting task and target information from playbook.
type Process ¶
type Process struct {
Concurrency int
Connector Connector
Playbook Playbook
Logs executor.Logs
Verbose bool
Verbose2 bool
Dry bool
Local bool
SSHShell string
SSHTempDir string
Skip []string
Only []string
}
Process is a struct that holds the information needed to run a process. It responsible for running a task on a target hosts.
func (*Process) Gen ¶ added in v1.6.0
Gen generates the list target hosts for a given target, applying templates.
Click to show internal directories.
Click to hide internal directories.